@@ -39,6 +39,8 @@ private Q_SLOTS:
     void testFindMatchingFoldingMarker();
     void testUpdateFoldingMarkersHighlighting();
     void testDdisplayRangeChangedEmitted();
+    void testCrashOnPasteInOverwriteMode();
+    void testCommandBarSearchReplace();
 };
 
 #endif // KATE_VIEW_TEST_H
